/*
 * SSD1306xLED - Drivers for SSD1306 controlled dot matrix OLED/PLED 128x64 displays
 *
 * @created: 2014-08-12
 * @author: Neven Boyanov
 *
 * Source code available at: https://bitbucket.org/tinusaur/ssd1306xled
 *
 */

// ----------------------------------------------------------------------------

#include <avr/pgmspace.h>

// ----------------------------------------------------------------------------

/* Standard ASCII 8x16 font */
const uint8_t ssd1306xled_font16x32 [] PROGMEM = {
	// @0 ',' (16 pixels wide)
	0x00, 0x00, 0x00, 0x00, //          
	0x00, 0x00, 0x00, 0x00, //          
	0x00, 0x00, 0x00, 0x00, //          
	0x00, 0x00, 0x00, 0x00, //          
	0x00, 0x00, 0x00, 0x00, //          
	0x40, 0x00, 0x00, 0x00, //  #       
	0xE3, 0x80, 0x00, 0x00, // ###   ###
	0x7F, 0x80, 0x00, 0x00, //  ########
	0x3F, 0x80, 0x00, 0x00, //   #######
	0x00, 0x00, 0x00, 0x00, //          
	0x00, 0x00, 0x00, 0x00, //          
	0x00, 0x00, 0x00, 0x00, //          
	0x00, 0x00, 0x00, 0x00, //          
	0x00, 0x00, 0x00, 0x00, //          
	0x00, 0x00, 0x00, 0x00, //          
	0x00, 0x00, 0x00, 0x00, //          

	// @32 '-' (16 pixels wide)
	0x00, 0x00, 0x00,0x00,  //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0xE0, 0x00, //                 ###
	0x00, 0x00, 0xE0, 0x00, //                 ###
	0x00, 0x00, 0xE0, 0x00, //                 ###
	0x00, 0x00, 0xE0, 0x00, //                 ###
	0x00, 0x00, 0xE0, 0x00, //                 ###
	0x00, 0x00, 0xE0, 0x00, //                 ###
	0x00, 0x00, 0xE0, 0x00, //                 ###
	0x00, 0x00, 0xE0, 0x00, //                 ###
	0x00, 0x00, 0xE0, 0x00, //                 ###
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    

	// @48 '.' (16 pixels wide)
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0xE0, 0x00, 0x00, 0x00, // ###
	0xE0, 0x00, 0x00, 0x00, // ###
	0xE0, 0x00, 0x00, 0x00, // ###
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    
	0x00, 0x00, 0x00, 0x00, //    

	// @64 '/' (16 pixels wide)
	0x00, 0x00, 0x00, 0x00, //                              
	0x00, 0x00, 0x00, 0x00, //                              
	0x80, 0x00, 0x00, 0x00, // #                            
	0xF8, 0x00, 0x00, 0x00, // #####                        
	0xFF, 0x80, 0x00, 0x00, // #########                    
	0x7F, 0xF8, 0x00, 0x00, //  ############                
	0x07, 0xFF, 0x80, 0x00, //      ############            
	0x00, 0x7F, 0xF8, 0x00, //          ############        
	0x00, 0x07, 0xFF, 0x80, //              ############    
	0x00, 0x00, 0x7F, 0xF8, //                  ############
	0x00, 0x00, 0x07, 0xF8, //                      ########
	0x00, 0x00, 0x00, 0x78, //                          ####
	0x00, 0x00, 0x00, 0x00, //                              
	0x00, 0x00, 0x00, 0x00, //                              
	0x00, 0x00, 0x00, 0x00, //                              
	0x00, 0x00, 0x00, 0x00, //                              

	// @128 '0' (16 pixels wide)
	0x00, 0xFF, 0xF8, 0x00, //         #############        
	0x0F, 0xFF, 0xFF, 0x00, //     ####################     
	0x1F, 0xFF, 0xFF, 0xC0, //    #######################   
	0x3F, 0x00, 0x07, 0xE0, //   ######             ######  
	0x78, 0x00, 0x00, 0xF0, //  ####                   #### 
	0xF0, 0x00, 0x00, 0x78, // ####                     ####
	0xE0, 0x00, 0x00, 0x38, // ###                       ###
	0xE0, 0x00, 0x00, 0x38, // ###                       ###
	0xE0, 0x00, 0x00, 0x38, // ###                       ###
	0xF0, 0x00, 0x00, 0x78, // ####                     ####
	0x78, 0x00, 0x00, 0xF0, //  ####                   #### 
	0x3F, 0x00, 0x07, 0xE0, //   ######             ######  
	0x1F, 0xFF, 0xFF, 0xC0, //    #######################   
	0x07, 0xFF, 0xFF, 0x00, //      ###################     
	0x00, 0xFF, 0xF8, 0x00, //         #############        
	0x00, 0x00, 0x00, 0x00, //                              

	// @192 '1' (16 pixels wide)
	0x00, 0x00, 0x00, 0x00, //                              
	0x00, 0x00, 0x00, 0x00, //                              
	0x00, 0x00, 0x38, 0x00, //                   ###        
	0x00, 0x00, 0x1C, 0x00, //                    ###       
	0x00, 0x00, 0x0E, 0x00, //                     ###      
	0x00, 0x00, 0x0F, 0x00, //                     ####     
	0x00, 0x00, 0x07, 0x80, //                      ####    
	0x00, 0x00, 0x03, 0xC0, //                       ####   
	0xFF, 0xFF, 0xFF, 0xF0, // ############################ 
	0xFF, 0xFF, 0xFF, 0xF8, // #############################
	0xFF, 0xFF, 0xFF, 0xF8, // #############################
	0x00, 0x00, 0x00, 0x00, //                              
	0x00, 0x00, 0x00, 0x00, //                              
	0x00, 0x00, 0x00, 0x00, //                              
	0x00, 0x00, 0x00, 0x00, //                              
	0x00, 0x00, 0x00, 0x00, //                              

	// @256 '2' (16 pixels wide)
	0xE0, 0x00, 0x0E, 0x00, // ###                 ###      
	0xF8, 0x00, 0x0F, 0xC0, // #####               ######   
	0xFE, 0x00, 0x0F, 0xE0, // #######             #######  
	0xFF, 0x00, 0x01, 0xF0, // ########               ##### 
	0xEF, 0x80, 0x00, 0x70, // ### #####                ### 
	0xE7, 0xC0, 0x00, 0x78, // ###  #####               ####
	0xE1, 0xE0, 0x00, 0x38, // ###    ####               ###
	0xE0, 0xF0, 0x00, 0x38, // ###     ####              ###
	0xE0, 0x78, 0x00, 0x38, // ###      ####             ###
	0xE0, 0x3E, 0x00, 0x38, // ###       #####           ###
	0xE0, 0x1F, 0x00, 0x78, // ###        #####         ####
	0xE0, 0x0F, 0xC1, 0xF0, // ###         ######     ##### 
	0xE0, 0x03, 0xFF, 0xE0, // ###           #############  
	0xE0, 0x01, 0xFF, 0xC0, // ###            ###########   
	0xE0, 0x00, 0x3F, 0x00, // ###               ######     
	0x00, 0x00, 0x00, 0x00, //                              

	// @320 '3' (16 pixels wide)
	0x07, 0x00, 0x03, 0x00, //      ###              ##     
	0x1F, 0x00, 0x03, 0xC0, //    #####              ####   
	0x3F, 0x00, 0x03, 0xE0, //   ######              #####  
	0x7C, 0x00, 0x00, 0xF0, //  #####                  #### 
	0x70, 0x00, 0x00, 0x78, //  ###                     ####
	0xE0, 0x00, 0x00, 0x38, // ###                       ###
	0xE0, 0x03, 0x80, 0x38, // ###           ###         ###
	0xE0, 0x03, 0x80, 0x38, // ###           ###         ###
	0xE0, 0x03, 0x80, 0x38, // ###           ###         ###
	0xF0, 0x03, 0xC0, 0x78, // ####          ####       ####
	0x70, 0x07, 0xE0, 0xF0, //  ###         ######     #### 
	0x7C, 0x1F, 0xFF, 0xE0, //  #####     ################  
	0x3F, 0xFE, 0x7F, 0xC0, //   #############  #########   
	0x1F, 0xFC, 0x1F, 0x80, //    ###########     ######    
	0x03, 0xF0, 0x00, 0x00, //       ######                 
	0x00, 0x00, 0x00, 0x00, //                              

	// @384 '4' (16 pixels wide)
	0x01, 0xE0, 0x00, 0x00, //        ####                  
	0x01, 0xF8, 0x00, 0x00, //        ######                
	0x01, 0xFE, 0x00, 0x00, //        ########              
	0x01, 0xDF, 0x80, 0x00, //        ### ######            
	0x01, 0xC7, 0xE0, 0x00, //        ###   ######          
	0x01, 0xC1, 0xF0, 0x00, //        ###     #####         
	0x01, 0xC0, 0x7C, 0x00, //        ###       #####       
	0x01, 0xC0, 0x3F, 0x00, //        ###        ######     
	0x01, 0xC0, 0x0F, 0xC0, //        ###          ######   
	0x01, 0xC0, 0x03, 0xF0, //        ###            ###### 
	0xFF, 0xFF, 0xFF, 0xF8, // #############################
	0xFF, 0xFF, 0xFF, 0xF8, // #############################
	0xFF, 0xFF, 0xFF, 0xF8, // #############################
	0x01, 0xC0, 0x00, 0x00, //        ###                   
	0x01, 0xC0, 0x00, 0x00, //        ###                   
	0x01, 0xC0, 0x00, 0x00, //        ###                   

	// @448 '5' (16 pixels wide)
	0x07, 0x03, 0xC0, 0x00, //      ###      ####           
	0x1F, 0x03, 0xFF, 0x80, //    #####      ###########    
	0x3F, 0x03, 0xFF, 0xF8, //   ######      ###############
	0x7C, 0x01, 0xFF, 0xF8, //  #####         ##############
	0x70, 0x00, 0xE0, 0x78, //  ###            ###      ####
	0xE0, 0x00, 0x70, 0x38, // ###              ###      ###
	0xE0, 0x00, 0x70, 0x38, // ###              ###      ###
	0xE0, 0x00, 0x70, 0x38, // ###              ###      ###
	0xE0, 0x00, 0x70, 0x38, // ###              ###      ###
	0xF0, 0x00, 0xF0, 0x38, // ####            ####      ###
	0x78, 0x01, 0xE0, 0x38, //  ####          ####       ###
	0x7E, 0x03, 0xE0, 0x38, //  ######       #####       ###
	0x1F, 0xFF, 0xC0, 0x38, //    ###############        ###
	0x0F, 0xFF, 0x80, 0x38, //     #############         ###
	0x01, 0xFC, 0x00, 0x00, //        #######               
	0x00, 0x00, 0x00, 0x00, //                              

	// @512 '6' (16 pixels wide)
	0x00, 0xFF, 0xF0, 0x00, //         ############         
	0x0F, 0xFF, 0xFF, 0x00, //     ####################     
	0x1F, 0xFF, 0xFF, 0xC0, //    #######################   
	0x3E, 0x07, 0x83, 0xE0, //   #####      ####     #####  
	0x78, 0x01, 0xC0, 0xF0, //  ####          ###      #### 
	0xF0, 0x01, 0xC0, 0x70, // ####           ###       ### 
	0xE0, 0x00, 0xE0, 0x38, // ###             ###       ###
	0xE0, 0x00, 0xE0, 0x38, // ###             ###       ###
	0xE0, 0x00, 0xE0, 0x38, // ###             ###       ###
	0xF0, 0x01, 0xE0, 0x38, // ####           ####       ###
	0x78, 0x01, 0xC0, 0x78, //  ####          ###       ####
	0x7C, 0x07, 0xC0, 0xF0, //  #####       #####      #### 
	0x3F, 0xFF, 0x83, 0xE0, //   ###############     #####  
	0x0F, 0xFF, 0x03, 0xC0, //     ############      ####   
	0x03, 0xFC, 0x03, 0x00, //       ########        ##     
	0x00, 0x00, 0x00, 0x00, //                              

	// @576 '7' (16 pixels wide)
	0x00, 0x00, 0x00, 0x38, //                           ###
	0x00, 0x00, 0x00, 0x38, //                           ###
	0x00, 0x00, 0x00, 0x38, //                           ###
	0xF8, 0x00, 0x00, 0x38, // #####                     ###
	0xFF, 0xC0, 0x00, 0x38, // ##########                ###
	0xFF, 0xF8, 0x00, 0x38, // #############             ###
	0x07, 0xFF, 0x00, 0x38, //      ###########          ###
	0x00, 0x3F, 0xC0, 0x38, //           ########        ###
	0x00, 0x07, 0xF0, 0x38, //              #######      ###
	0x00, 0x00, 0xFC, 0x38, //                 ######    ###
	0x00, 0x00, 0x3F, 0x38, //                   ######  ###
	0x00, 0x00, 0x0F, 0xB8, //                     ##### ###
	0x00, 0x00, 0x03, 0xF8, //                       #######
	0x00, 0x00, 0x00, 0xF8, //                         #####
	0x00, 0x00, 0x00, 0x38, //                           ###
	0x00, 0x00, 0x00, 0x00, //                              

	// @640 '8' (16 pixels wide)
	0x07, 0xF0, 0x00, 0x00, //      #######                 
	0x1F, 0xFC, 0x1F, 0x80, //    ###########     ######    
	0x3F, 0xFE, 0x7F, 0xE0, //   #############  ##########  
	0x7C, 0x1E, 0xFF, 0xF0, //  #####     #### ############ 
	0x70, 0x07, 0xE0, 0xF0, //  ###         ######     #### 
	0xF0, 0x03, 0xC0, 0x78, // ####          ####       ####
	0xE0, 0x03, 0x80, 0x38, // ###           ###         ###
	0xE0, 0x03, 0x80, 0x38, // ###           ###         ###
	0xE0, 0x03, 0x80, 0x38, // ###           ###         ###
	0xE0, 0x07, 0xC0, 0x78, // ###          #####       ####
	0x70, 0x07, 0xE0, 0xF0, //  ###         ######     #### 
	0x7C, 0x1E, 0xFF, 0xF0, //  #####     #### ############ 
	0x3F, 0xFC, 0x7F, 0xC0, //   ############   #########   
	0x1F, 0xF8, 0x1F, 0x80, //    ##########      ######    
	0x07, 0xF0, 0x00, 0x00, //      #######                 
	0x00, 0x00, 0x00, 0x00, //                              

	// @704 '9' (16 pixels wide)
	0x06, 0x00, 0xFE, 0x00, //      ##         #######      
	0x1E, 0x07, 0xFF, 0xC0, //    ####      #############   
	0x7E, 0x0F, 0xFF, 0xE0, //  ######     ###############  
	0x78, 0x1F, 0x03, 0xF0, //  ####      #####      ###### 
	0xF0, 0x1C, 0x00, 0xF0, // ####       ###          #### 
	0xE0, 0x3C, 0x00, 0x78, // ###       ####           ####
	0xE0, 0x38, 0x00, 0x38, // ###       ###             ###
	0xE0, 0x38, 0x00, 0x38, // ###       ###             ###
	0xE0, 0x38, 0x00, 0x38, // ###       ###             ###
	0x70, 0x1C, 0x00, 0x78, //  ###       ###           ####
	0x78, 0x1C, 0x00, 0xF0, //  ####      ###          #### 
	0x3E, 0x0F, 0x01, 0xE0, //   #####     ####       ####  
	0x1F, 0xFF, 0xFF, 0xC0, //    #######################   
	0x07, 0xFF, 0xFF, 0x80, //      ####################    
	0x00, 0x7F, 0xF8, 0x00, //          ############        
	0x00, 0x00, 0x00, 0x00, //                              

	// @768 ':' (16 pixels wide)
	0x00, 0x00, 0x00, //                      
	0x00, 0x00, 0x00, 0x00, //                      
	0x00, 0x00, 0x00, 0x00, //                      
	0x00, 0x00, 0x00, 0x00, //                      
	0x00, 0x00, 0x00, 0x00, //                      
	0x00, 0x00, 0x00, 0x00, //                      
	0x00, 0xE0, 0x00, 0x38, // ###               ###
	0x00, 0xE0, 0x00, 0x38, // ###               ###
	0x00, 0xE0, 0x00, 0x38, // ###               ###
	0x00, 0x00, 0x00, 0x00, //                      
	0x00, 0x00, 0x00, 0x00, //                      
	0x00, 0x00, 0x00, 0x00, //                      
	0x00, 0x00, 0x00, 0x00, //                      
	0x00, 0x00, 0x00, 0x00, //                      
	0x00, 0x00, 0x00, 0x00, //                      
	0x00, 0x00, 0x00, 0x00, //             
};
